@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the Linux console (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2002 by The BRLTTY Team. All rights reserved.
+ * Copyright (C) 1995-2003 by The BRLTTY Team. All rights reserved.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -16,14 +16,14 @@
  */
 
 /*
-#	Name:             ISO/IEC 8859-8:1999 to Unicode
+#	Name:             ISO/IEC 8859-16:2001 to Unicode
 #	Unicode version:  3.0
-#	Table version:    1.1
+#	Table version:    1.0
 #	Table format:     Format A
-#	Date:             2000-Jan-03
-#	Authors:          Ken Whistler <kenw@sybase.com>
+#	Date:             2001 July 26
+#	Authors:          Markus Kuhn <mkuhn@acm.org>
 #
-#	Copyright (c) 1991-1999 Unicode, Inc.  All Rights reserved.
+#	Copyright (c) 1999-2001 Unicode, Inc.  All Rights reserved.
 #
 #	This file is provided as-is by Unicode, Inc. (The Unicode Consortium).
 #	No claims are made as to fitness for any particular purpose.  No
@@ -42,20 +42,14 @@
 #	General notes:
 #
 #	This table contains the data the Unicode Consortium has on how
-#       ISO/IEC 8859-8:1999 characters map into Unicode.
+#       ISO/IEC 8859-16:2001 characters map into Unicode.
 #
 #	Format:  Three tab-separated columns
-#		 Column #1 is the ISO/IEC 8859-8 code (in hex as 0xXX)
+#		 Column #1 is the ISO/IEC 8859-16 code (in hex as 0xXX)
 #		 Column #2 is the Unicode (in hex as 0xXXXX)
 #		 Column #3 the Unicode name (follows a comment sign, '#')
 #
-#	The entries are in ISO/IEC 8859-8 order.
-#
-#	Version history
-#	1.0 version updates 0.1 version by adding mappings for all
-#	control characters.
-#       1.1 version updates to the published 8859-8:1999, correcting
-#          the mapping of 0xAF and adding mappings for LRM and RLM.
+#	The entries are in ISO/IEC 8859-16 order.
 #
 #	Updated versions of this file may be found in:
 #		<ftp://ftp.unicode.org/Public/MAPPINGS/>
@@ -225,63 +219,98 @@
 [0x9E]=0x009E, //	<control>
 [0x9F]=0x009F, //	<control>
 [0xA0]=0x00A0, //	NO-BREAK SPACE
-[0xA2]=0x00A2, //	CENT SIGN
-[0xA3]=0x00A3, //	POUND SIGN
-[0xA4]=0x00A4, //	CURRENCY SIGN
-[0xA5]=0x00A5, //	YEN SIGN
-[0xA6]=0x00A6, //	BROKEN BAR
+[0xA1]=0x0104, //	LATIN CAPITAL LETTER A WITH OGONEK
+[0xA2]=0x0105, //	LATIN SMALL LETTER A WITH OGONEK
+[0xA3]=0x0141, //	LATIN CAPITAL LETTER L WITH STROKE
+[0xA4]=0x20AC, //	EURO SIGN
+[0xA5]=0x201E, //	DOUBLE LOW-9 QUOTATION MARK
+[0xA6]=0x0160, //	LATIN CAPITAL LETTER S WITH CARON
 [0xA7]=0x00A7, //	SECTION SIGN
-[0xA8]=0x00A8, //	DIAERESIS
+[0xA8]=0x0161, //	LATIN SMALL LETTER S WITH CARON
 [0xA9]=0x00A9, //	COPYRIGHT SIGN
-[0xAA]=0x00D7, //	MULTIPLICATION SIGN
+[0xAA]=0x0218, //	LATIN CAPITAL LETTER S WITH COMMA BELOW
 [0xAB]=0x00AB, //	LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
-[0xAC]=0x00AC, //	NOT SIGN
+[0xAC]=0x0179, //	LATIN CAPITAL LETTER Z WITH ACUTE
 [0xAD]=0x00AD, //	SOFT HYPHEN
-[0xAE]=0x00AE, //	REGISTERED SIGN
-[0xAF]=0x00AF, //	MACRON
+[0xAE]=0x017A, //	LATIN SMALL LETTER Z WITH ACUTE
+[0xAF]=0x017B, //	LATIN CAPITAL LETTER Z WITH DOT ABOVE
 [0xB0]=0x00B0, //	DEGREE SIGN
 [0xB1]=0x00B1, //	PLUS-MINUS SIGN
-[0xB2]=0x00B2, //	SUPERSCRIPT TWO
-[0xB3]=0x00B3, //	SUPERSCRIPT THREE
-[0xB4]=0x00B4, //	ACUTE ACCENT
-[0xB5]=0x00B5, //	MICRO SIGN
+[0xB2]=0x010C, //	LATIN CAPITAL LETTER C WITH CARON
+[0xB3]=0x0142, //	LATIN SMALL LETTER L WITH STROKE
+[0xB4]=0x017D, //	LATIN CAPITAL LETTER Z WITH CARON
+[0xB5]=0x201D, //	RIGHT DOUBLE QUOTATION MARK
 [0xB6]=0x00B6, //	PILCROW SIGN
 [0xB7]=0x00B7, //	MIDDLE DOT
-[0xB8]=0x00B8, //	CEDILLA
-[0xB9]=0x00B9, //	SUPERSCRIPT ONE
-[0xBA]=0x00F7, //	DIVISION SIGN
+[0xB8]=0x017E, //	LATIN SMALL LETTER Z WITH CARON
+[0xB9]=0x010D, //	LATIN SMALL LETTER C WITH CARON
+[0xBA]=0x0219, //	LATIN SMALL LETTER S WITH COMMA BELOW
 [0xBB]=0x00BB, //	RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-[0xBC]=0x00BC, //	VULGAR FRACTION ONE QUARTER
-[0xBD]=0x00BD, //	VULGAR FRACTION ONE HALF
-[0xBE]=0x00BE, //	VULGAR FRACTION THREE QUARTERS
-[0xDF]=0x2017, //	DOUBLE LOW LINE
-[0xE0]=0x05D0, //	HEBREW LETTER ALEF
-[0xE1]=0x05D1, //	HEBREW LETTER BET
-[0xE2]=0x05D2, //	HEBREW LETTER GIMEL
-[0xE3]=0x05D3, //	HEBREW LETTER DALET
-[0xE4]=0x05D4, //	HEBREW LETTER HE
-[0xE5]=0x05D5, //	HEBREW LETTER VAV
-[0xE6]=0x05D6, //	HEBREW LETTER ZAYIN
-[0xE7]=0x05D7, //	HEBREW LETTER HET
-[0xE8]=0x05D8, //	HEBREW LETTER TET
-[0xE9]=0x05D9, //	HEBREW LETTER YOD
-[0xEA]=0x05DA, //	HEBREW LETTER FINAL KAF
-[0xEB]=0x05DB, //	HEBREW LETTER KAF
-[0xEC]=0x05DC, //	HEBREW LETTER LAMED
-[0xED]=0x05DD, //	HEBREW LETTER FINAL MEM
-[0xEE]=0x05DE, //	HEBREW LETTER MEM
-[0xEF]=0x05DF, //	HEBREW LETTER FINAL NUN
-[0xF0]=0x05E0, //	HEBREW LETTER NUN
-[0xF1]=0x05E1, //	HEBREW LETTER SAMEKH
-[0xF2]=0x05E2, //	HEBREW LETTER AYIN
-[0xF3]=0x05E3, //	HEBREW LETTER FINAL PE
-[0xF4]=0x05E4, //	HEBREW LETTER PE
-[0xF5]=0x05E5, //	HEBREW LETTER FINAL TSADI
-[0xF6]=0x05E6, //	HEBREW LETTER TSADI
-[0xF7]=0x05E7, //	HEBREW LETTER QOF
-[0xF8]=0x05E8, //	HEBREW LETTER RESH
-[0xF9]=0x05E9, //	HEBREW LETTER SHIN
-[0xFA]=0x05EA, //	HEBREW LETTER TAV
-[0xFD]=0x200E, //	LEFT-TO-RIGHT MARK
-[0xFE]=0x200F  //	RIGHT-TO-LEFT MARK
-
+[0xBC]=0x0152, //	LATIN CAPITAL LIGATURE OE
+[0xBD]=0x0153, //	LATIN SMALL LIGATURE OE
+[0xBE]=0x0178, //	LATIN CAPITAL LETTER Y WITH DIAERESIS
+[0xBF]=0x017C, //	LATIN SMALL LETTER Z WITH DOT ABOVE
+[0xC0]=0x00C0, //	LATIN CAPITAL LETTER A WITH GRAVE
+[0xC1]=0x00C1, //	LATIN CAPITAL LETTER A WITH ACUTE
+[0xC2]=0x00C2, //	LATIN CAPITAL LETTER A WITH CIRCUMFLEX
+[0xC3]=0x0102, //	LATIN CAPITAL LETTER A WITH BREVE
+[0xC4]=0x00C4, //	LATIN CAPITAL LETTER A WITH DIAERESIS
+[0xC5]=0x0106, //	LATIN CAPITAL LETTER C WITH ACUTE
+[0xC6]=0x00C6, //	LATIN CAPITAL LETTER AE
+[0xC7]=0x00C7, //	LATIN CAPITAL LETTER C WITH CEDILLA
+[0xC8]=0x00C8, //	LATIN CAPITAL LETTER E WITH GRAVE
+[0xC9]=0x00C9, //	LATIN CAPITAL LETTER E WITH ACUTE
+[0xCA]=0x00CA, //	LATIN CAPITAL LETTER E WITH CIRCUMFLEX
+[0xCB]=0x00CB, //	LATIN CAPITAL LETTER E WITH DIAERESIS
+[0xCC]=0x00CC, //	LATIN CAPITAL LETTER I WITH GRAVE
+[0xCD]=0x00CD, //	LATIN CAPITAL LETTER I WITH ACUTE
+[0xCE]=0x00CE, //	LATIN CAPITAL LETTER I WITH CIRCUMFLEX
+[0xCF]=0x00CF, //	LATIN CAPITAL LETTER I WITH DIAERESIS
+[0xD0]=0x0110, //	LATIN CAPITAL LETTER D WITH STROKE
+[0xD1]=0x0143, //	LATIN CAPITAL LETTER N WITH ACUTE
+[0xD2]=0x00D2, //	LATIN CAPITAL LETTER O WITH GRAVE
+[0xD3]=0x00D3, //	LATIN CAPITAL LETTER O WITH ACUTE
+[0xD4]=0x00D4, //	LATIN CAPITAL LETTER O WITH CIRCUMFLEX
+[0xD5]=0x0150, //	LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
+[0xD6]=0x00D6, //	LATIN CAPITAL LETTER O WITH DIAERESIS
+[0xD7]=0x015A, //	LATIN CAPITAL LETTER S WITH ACUTE
+[0xD8]=0x0170, //	LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
+[0xD9]=0x00D9, //	LATIN CAPITAL LETTER U WITH GRAVE
+[0xDA]=0x00DA, //	LATIN CAPITAL LETTER U WITH ACUTE
+[0xDB]=0x00DB, //	LATIN CAPITAL LETTER U WITH CIRCUMFLEX
+[0xDC]=0x00DC, //	LATIN CAPITAL LETTER U WITH DIAERESIS
+[0xDD]=0x0118, //	LATIN CAPITAL LETTER E WITH OGONEK
+[0xDE]=0x021A, //	LATIN CAPITAL LETTER T WITH COMMA BELOW
+[0xDF]=0x00DF, //	LATIN SMALL LETTER SHARP S
+[0xE0]=0x00E0, //	LATIN SMALL LETTER A WITH GRAVE
+[0xE1]=0x00E1, //	LATIN SMALL LETTER A WITH ACUTE
+[0xE2]=0x00E2, //	LATIN SMALL LETTER A WITH CIRCUMFLEX
+[0xE3]=0x0103, //	LATIN SMALL LETTER A WITH BREVE
+[0xE4]=0x00E4, //	LATIN SMALL LETTER A WITH DIAERESIS
+[0xE5]=0x0107, //	LATIN SMALL LETTER C WITH ACUTE
+[0xE6]=0x00E6, //	LATIN SMALL LETTER AE
+[0xE7]=0x00E7, //	LATIN SMALL LETTER C WITH CEDILLA
+[0xE8]=0x00E8, //	LATIN SMALL LETTER E WITH GRAVE
+[0xE9]=0x00E9, //	LATIN SMALL LETTER E WITH ACUTE
+[0xEA]=0x00EA, //	LATIN SMALL LETTER E WITH CIRCUMFLEX
+[0xEB]=0x00EB, //	LATIN SMALL LETTER E WITH DIAERESIS
+[0xEC]=0x00EC, //	LATIN SMALL LETTER I WITH GRAVE
+[0xED]=0x00ED, //	LATIN SMALL LETTER I WITH ACUTE
+[0xEE]=0x00EE, //	LATIN SMALL LETTER I WITH CIRCUMFLEX
+[0xEF]=0x00EF, //	LATIN SMALL LETTER I WITH DIAERESIS
+[0xF0]=0x0111, //	LATIN SMALL LETTER D WITH STROKE
+[0xF1]=0x0144, //	LATIN SMALL LETTER N WITH ACUTE
+[0xF2]=0x00F2, //	LATIN SMALL LETTER O WITH GRAVE
+[0xF3]=0x00F3, //	LATIN SMALL LETTER O WITH ACUTE
+[0xF4]=0x00F4, //	LATIN SMALL LETTER O WITH CIRCUMFLEX
+[0xF5]=0x0151, //	LATIN SMALL LETTER O WITH DOUBLE ACUTE
+[0xF6]=0x00F6, //	LATIN SMALL LETTER O WITH DIAERESIS
+[0xF7]=0x015B, //	LATIN SMALL LETTER S WITH ACUTE
+[0xF8]=0x0171, //	LATIN SMALL LETTER U WITH DOUBLE ACUTE
+[0xF9]=0x00F9, //	LATIN SMALL LETTER U WITH GRAVE
+[0xFA]=0x00FA, //	LATIN SMALL LETTER U WITH ACUTE
+[0xFB]=0x00FB, //	LATIN SMALL LETTER U WITH CIRCUMFLEX
+[0xFC]=0x00FC, //	LATIN SMALL LETTER U WITH DIAERESIS
+[0xFD]=0x0119, //	LATIN SMALL LETTER E WITH OGONEK
+[0xFE]=0x021B, //	LATIN SMALL LETTER T WITH COMMA BELOW
+[0xFF]=0x00FF  //	LATIN SMALL LETTER Y WITH DIAERESIS
